Learn R Programming

MEIGOR (version 1.6.0)

eucl_dist: Computes the euclidean distance between the rows of two different matrices

Description

This functions is used internally by essR to compute the euclidean distance between the rows of two different matrices. The matrices must have the same number of columns.

Arguments