Learn R Programming

MEIGOR (version 1.6.0)

solnp_ineq: Gateway function to evaluate the inequality constraints when solnp is invoked as local solver

Description

This function is used internally by essR to evaluate the inequality constraints when solnp is invoked as local solver

Arguments