Learn R Programming

MEIGOR (version 1.6.0)

ssm_optset: Assigns values to the options defined by the user

Description

This function is used internally by essR for assigning values to the options defined by the user

Arguments